Struct sp_consensus_beefy::VoteMessage
source · pub struct VoteMessage<Number, Id, Signature> {
pub commitment: Commitment<Number>,
pub id: Id,
pub signature: Signature,
}Expand description
BEEFY vote message.
A vote message is a direct vote created by a BEEFY node on every voting round and is gossiped to its peers.
Fields
commitment: Commitment<Number>Commit to information extracted from a finalized block
id: IdNode authority id
signature: SignatureNode signature